Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(561)

Unified Diff: content/browser/frame_host/navigator_impl.h

Issue 1422333009: OOPIF: History navigations for new child frames. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Improve comment. Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/frame_host/navigator.cc ('k') | content/browser/frame_host/navigator_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/navigator_impl.h
diff --git a/content/browser/frame_host/navigator_impl.h b/content/browser/frame_host/navigator_impl.h
index 775b16f57737744100246f9ffde4630fda4f9a75..5a7a21cd8fa2c3c22c5c534eee51525216357173 100644
--- a/content/browser/frame_host/navigator_impl.h
+++ b/content/browser/frame_host/navigator_impl.h
@@ -56,6 +56,8 @@ class CONTENT_EXPORT NavigatorImpl : public Navigator {
const FrameNavigationEntry& frame_entry,
NavigationController::ReloadType reload_type,
bool is_same_document_history_load) override;
+ bool NavigateNewChildFrame(RenderFrameHostImpl* render_frame_host,
+ const std::string& unique_name) override;
void RequestOpenURL(RenderFrameHostImpl* render_frame_host,
const GURL& url,
SiteInstance* source_site_instance,
@@ -98,13 +100,15 @@ class CONTENT_EXPORT NavigatorImpl : public Navigator {
friend class NavigatorTestWithBrowserSideNavigation;
~NavigatorImpl() override;
// Navigates to the given entry, which must be the pending entry. Private
// because all callers should use NavigateToPendingEntry.
bool NavigateToEntry(FrameTreeNode* frame_tree_node,
const FrameNavigationEntry& frame_entry,
const NavigationEntryImpl& entry,
NavigationController::ReloadType reload_type,
- bool is_same_document_history_load);
+ bool is_same_document_history_load,
+ bool is_pending_entry);
bool ShouldAssignSiteForURL(const GURL& url);
« no previous file with comments | « content/browser/frame_host/navigator.cc ('k') | content/browser/frame_host/navigator_impl.cc » ('j') | no next file with comments »
@@ -98,13 +100,15 @@ class CONTENT_EXPORT NavigatorImpl : public Navigator {
friend class NavigatorTestWithBrowserSideNavigation;
~NavigatorImpl() override;
- // Navigates to the given entry, which must be the pending entry. Private
- // because all callers should use NavigateToPendingEntry.
+ // Navigates to the given entry, which might be the pending entry (if
+ // |is_pending_entry| is true). Private because all callers should use either
+ // NavigateToPendingEntry or NavigateToNewChildFrame.
bool NavigateToEntry(FrameTreeNode* frame_tree_node,
const FrameNavigationEntry& frame_entry,

Powered by Google App Engine
This is Rietveld 408576698